diff libpurple/protocols/qq/group_conv.h @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b
line wrap: on
line diff
--- a/libpurple/protocols/qq/group_conv.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/qq/group_conv.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file group_conv.h
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -28,7 +28,7 @@
 #include "connection.h"
 #include "group.h"
 
-void qq_group_conv_show_window(GaimConnection *gc, qq_group *group);
-void qq_group_conv_refresh_online_member(GaimConnection *gc, qq_group *group);
+void qq_group_conv_show_window(PurpleConnection *gc, qq_group *group);
+void qq_group_conv_refresh_online_member(PurpleConnection *gc, qq_group *group);
 
 #endif
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.